# Kotlin Style Checker
____

This python library checks Kotlin code conventions usage and fixes them where it can.
____

It also can be used from command line

Usage: 
kotlin_style_checker --input_path